@@ -8,7 +8,7 @@ use Encode;
 use Try::Tiny;
 use YAML::XS;
 
-our $VERSION = "0.012_004";
+our $VERSION = "0.013_001";
 $VERSION = eval $VERSION;
 
 requires 'db';
@@ -20,7 +20,7 @@ Giddy::Role::DocumentLoader - Provides document loading methods for Giddy::Colle
 
 =head1 VERSION
 
-version 0.012_004
+version 0.013_001
 
 =head1 SYNOPSIS
 
@@ -54,9 +54,10 @@ sub _load_document_file {
 		my $doc = Load("---\n$yaml");
 		$doc->{_body} = $body;
 		$doc->{_name} = $name;
+		$doc->{_coll} = $self->path;
 		return $doc;
 	} catch {
-		return { _body => $body, _name => $name };
+		return { _body => $body, _name => $name, _coll => $self->path };
 	};
 }
 
@@ -89,6 +90,7 @@ sub _load_document_dir {
 
 	$doc->{_name} = $name
 		if $doc && scalar keys %$doc;
+	$doc->{_coll} = $self->path;
 
 	return $doc;
 }
